@@ -72,6 +72,9 @@ lxd_opts = [
     cfg.StrOpt('root_dir',
                default='/var/lib/lxd/',
                help='Default LXD directory'),
+    cfg.StrOpt('pool',
+               default=None,
+               help='LXD Storage pool to use with LXD >= 2.9'),
     cfg.IntOpt('timeout',
                default=-1,
                help='Default LXD timeout'),
@@ -415,7 +418,7 @@ class LXDDriver(driver.ComputeDriver):
                     'path': '/config-drive',
                     'source': configdrive_path,
                     'type': 'disk',
-                    'readonly': True,
+                    'readonly': 'True',
                 }
             }
             profile.devices.update(config_drive)
